@@ -3,7 +3,7 @@ package File::Spec::Epoc;
 use strict;
 use vars qw($VERSION @ISA);
 
-$VERSION = '3.2701';
+$VERSION = "-1";
 
 require File::Spec::Unix;
 @ISA = qw(File::Spec::Unix);
@@ -24,6 +24,10 @@ the semantics.
 
 This package is still work in progress ;-)
 
+=head1 AUTHORS
+
+o.flebbe@gmx.de
+
 =cut
 
 sub case_tolerant {
@@ -45,7 +49,6 @@ path. On UNIX eliminated successive slashes and successive "/.".
 
 sub canonpath {
     my ($self,$path) = @_;
-    return unless defined $path;
 
     $path =~ s|/+|/|g;                             # xx////xx  -> xx/xx
     $path =~ s|(/\.)+/|/|g;                        # xx/././xx -> xx/xx
@@ -57,17 +60,6 @@ sub canonpath {
 
 =pod
 
-=head1 AUTHOR
-
-o.flebbe@gmx.de
-
-=head1 COPYRIGHT
-
-Copyright (c) 2004 by the Perl 5 Porters.  All rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 See L<File::Spec> and L<File::Spec::Unix>.  This package overrides the
