@@ -3,7 +3,7 @@ package File::Spec::Unix;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '3.2701';
+$VERSION = "-1";
 
 =head1 NAME
 
@@ -30,39 +30,30 @@ path. On UNIX eliminates successive slashes and successive "/.".
 
     $cpath = File::Spec->canonpath( $path ) ;
 
-Note that this does *not* collapse F<x/../y> sections into F<y>.  This
-is by design.  If F</foo> on your system is a symlink to F</bar/baz>,
-then F</foo/../quux> is actually F</bar/quux>, not F</quux> as a naive
-F<../>-removal would give you.  If you want to do this kind of
-processing, you probably want C<Cwd>'s C<realpath()> function to
-actually traverse the filesystem cleaning up paths like this.
-
 =cut
 
 sub canonpath {
     my ($self,$path) = @_;
-    return unless defined $path;
     
     # Handle POSIX-style node names beginning with double slash (qnx, nto)
+    # Handle network path names beginning with double slash (cygwin)
     # (POSIX says: "a pathname that begins with two successive slashes
     # may be interpreted in an implementation-defined manner, although
     # more than two leading slashes shall be treated as a single slash.")
     my $node = '';
-    my $double_slashes_special = $^O eq 'qnx' || $^O eq 'nto';
-    if ( $double_slashes_special && $path =~ s{^(//[^/]+)(?:/|\z)}{/}s ) {
+    if ( $^O =~ m/^(?:qnx|nto|cygwin)$/ && $path =~ s:^(//[^/]+)(/|\z):/:s ) {
       $node = $1;
     }
     # This used to be
-    # $path =~ s|/+|/|g unless ($^O eq 'cygwin');
+    # $path =~ s|/+|/|g unless($^O eq 'cygwin');
     # but that made tests 29, 30, 35, 46, and 213 (as of #13272) to fail
     # (Mainly because trailing "" directories didn't get stripped).
     # Why would cygwin avoid collapsing multiple slashes into one? --jhi
-    $path =~ s|/{2,}|/|g;                            # xx////xx  -> xx/xx
-    $path =~ s{(?:/\.)+(?:/|\z)}{/}g;                # xx/././xx -> xx/xx
-    $path =~ s|^(?:\./)+||s unless $path eq "./";    # ./xx      -> xx
-    $path =~ s|^/(?:\.\./)+|/|;                      # /../../xx -> xx
-    $path =~ s|^/\.\.$|/|;                         # /..       -> /
-    $path =~ s|/\z|| unless $path eq "/";          # xx/       -> xx
+    $path =~ s|/+|/|g;                             # xx////xx  -> xx/xx
+    $path =~ s@(/\.)+(/|\Z(?!\n))@/@g;             # xx/././xx -> xx/xx
+    $path =~ s|^(\./)+||s unless $path eq "./";    # ./xx      -> xx
+    $path =~ s|^/(\.\./)+|/|s;                     # /../../xx -> xx
+    $path =~ s|/\Z(?!\n)|| unless $path eq "/";          # xx/       -> xx
     return "$node$path";
 }
 
@@ -160,7 +151,8 @@ sub _tmpdir {
 
 sub tmpdir {
     return $tmpdir if defined $tmpdir;
-    $tmpdir = $_[0]->_tmpdir( $ENV{TMPDIR}, "/tmp" );
+    my $self = shift;
+    $tmpdir = $self->_tmpdir( $ENV{TMPDIR}, "/tmp" );
 }
 
 =item updir
@@ -180,7 +172,7 @@ directory. (Does not strip symlinks, only '.', '..', and equivalents.)
 
 sub no_upwards {
     my $self = shift;
-    return grep(!/^\.{1,2}\z/s, @_);
+    return grep(!/^\.{1,2}\Z(?!\n)/s, @_);
 }
 
 =item case_tolerant
@@ -260,7 +252,7 @@ sub splitpath {
         $directory = $path;
     }
     else {
-        $path =~ m|^ ( (?: .* / (?: \.\.?\z )? )? ) ([^/]*) |xs;
+        $path =~ m|^ ( (?: .* / (?: \.\.?\Z(?!\n) )? )? ) ([^/]*) |xs;
         $directory = $1;
         $file      = $2;
     }
@@ -354,57 +346,52 @@ Based on code written by Shigio Yamaguchi.
 
 sub abs2rel {
     my($self,$path,$base) = @_;
-    $base = $self->_cwd() unless defined $base and length $base;
 
-    ($path, $base) = map $self->canonpath($_), $path, $base;
-
-    if (grep $self->file_name_is_absolute($_), $path, $base) {
-	($path, $base) = map $self->rel2abs($_), $path, $base;
+    # Clean up $path
+    if ( ! $self->file_name_is_absolute( $path ) ) {
+        $path = $self->rel2abs( $path ) ;
     }
     else {
-	# save a couple of cwd()s if both paths are relative
-	($path, $base) = map $self->catdir('/', $_), $path, $base;
+        $path = $self->canonpath( $path ) ;
     }
 
-    my ($path_volume) = $self->splitpath($path, 1);
-    my ($base_volume) = $self->splitpath($base, 1);
-
-    # Can't relativize across volumes
-    return $path unless $path_volume eq $base_volume;
-
-    my $path_directories = ($self->splitpath($path, 1))[1];
-    my $base_directories = ($self->splitpath($base, 1))[1];
-
-    # For UNC paths, the user might give a volume like //foo/bar that
-    # strictly speaking has no directory portion.  Treat it as if it
-    # had the root directory for that volume.
-    if (!length($base_directories) and $self->file_name_is_absolute($base)) {
-      $base_directories = $self->rootdir;
+    # Figure out the effective $base and clean it up.
+    if ( !defined( $base ) || $base eq '' ) {
+        $base = $self->_cwd();
+    }
+    elsif ( ! $self->file_name_is_absolute( $base ) ) {
+        $base = $self->rel2abs( $base ) ;
+    }
+    else {
+        $base = $self->canonpath( $base ) ;
     }
 
     # Now, remove all leading components that are the same
-    my @pathchunks = $self->splitdir( $path_directories );
-    my @basechunks = $self->splitdir( $base_directories );
+    my @pathchunks = $self->splitdir( $path);
+    my @basechunks = $self->splitdir( $base);
 
-    if ($base_directories eq $self->rootdir) {
-      shift @pathchunks;
-      return $self->canonpath( $self->catpath('', $self->catdir( @pathchunks ), '') );
-    }
-
-    while (@pathchunks && @basechunks && $self->_same($pathchunks[0], $basechunks[0])) {
+    while (@pathchunks && @basechunks && $pathchunks[0] eq $basechunks[0]) {
         shift @pathchunks ;
         shift @basechunks ;
     }
-    return $self->curdir unless @pathchunks || @basechunks;
+
+    $path = CORE::join( '/', @pathchunks );
+    $base = CORE::join( '/', @basechunks );
 
     # $base now contains the directories the resulting relative path 
-    # must ascend out of before it can descend to $path_directory.
-    my $result_dirs = $self->catdir( ($self->updir) x @basechunks, @pathchunks );
-    return $self->canonpath( $self->catpath('', $result_dirs, '') );
-}
+    # must ascend out of before it can descend to $path_directory.  So, 
+    # replace all names with $parentDir
+    $base =~ s|[^/]+|..|g ;
 
-sub _same {
-  $_[1] eq $_[2];
+    # Glue the two together, using a separator if necessary, and preventing an
+    # empty result.
+    if ( $path ne '' && $base ne '' ) {
+        $path = "$base/$path" ;
+    } else {
+        $path = "$base$path" ;
+    }
+
+    return $self->canonpath( $path ) ;
 }
 
 =item rel2abs()
@@ -458,13 +445,6 @@ sub rel2abs {
 
 =back
 
-=head1 COPYRIGHT
-
-Copyright (c) 2004 by the Perl 5 Porters.  All rights reserved.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 SEE ALSO
 
 L<File::Spec>
@@ -476,42 +456,7 @@ L<File::Spec>
 # File::Spec subclasses use this.
 sub _cwd {
     require Cwd;
-    Cwd::getcwd();
+    Cwd::cwd();
 }
 
-
-# Internal method to reduce xx\..\yy -> yy
-sub _collapse {
-    my($fs, $path) = @_;
-
-    my $updir  = $fs->updir;
-    my $curdir = $fs->curdir;
-
-    my($vol, $dirs, $file) = $fs->splitpath($path);
-    my @dirs = $fs->splitdir($dirs);
-    pop @dirs if @dirs && $dirs[-1] eq '';
-
-    my @collapsed;
-    foreach my $dir (@dirs) {
-        if( $dir eq $updir              and   # if we have an updir
-            @collapsed                  and   # and something to collapse
-            length $collapsed[-1]       and   # and its not the rootdir
-            $collapsed[-1] ne $updir    and   # nor another updir
-            $collapsed[-1] ne $curdir         # nor the curdir
-          ) 
-        {                                     # then
-            pop @collapsed;                   # collapse
-        }
-        else {                                # else
-            push @collapsed, $dir;            # just hang onto it
-        }
-    }
-
-    return $fs->catpath($vol,
-                        $fs->catdir(@collapsed),
-                        $file
-                       );
-}
-
-
 1;
