@@ -12,7 +12,7 @@ local $Params::Check::VERBOSE = 1;
 BEGIN {
     use vars        qw[$VERSION @ISA $STACK $CONFIG];
 
-    $VERSION    =   0.01;
+    $VERSION = "-1";
 
     $STACK      =   [];
 }
@@ -22,7 +22,7 @@ BEGIN {
 
 =head1 NAME
 
-Log::Message - A generic message storing mechanism;
+Log::Message -- A generic message storing mechanism;
 
 =head1 SYNOPSIS
 
