@@ -2,7 +2,7 @@ package CPANPLUS::Backend;
 
 use strict;
 
-use CPANPLUS::inc;
+
 use CPANPLUS::Error;
 use CPANPLUS::Configure;
 use CPANPLUS::Internals;
@@ -65,11 +65,11 @@ This information might be useful somehow to spawned processes.
 
 =head1 METHODS
 
-=head2 new( [CONFIG_OBJ | config => { ... }] )
+=head2 new( [CONFIGURE_OBJ] )
 
 This method returns a new C<CPANPLUS::Backend> object.
 This also initialises the config corresponding to this object.
-You have three choices in this:
+You have two choices in this:
 
 =over 4
 
@@ -77,11 +77,6 @@ You have three choices in this:
 
 This will be used verbatim.
 
-=item Provide a few options like config => { ... }
-
-These will override your existing config, but use your default
-config for options you didn't specify.
-
 =item No arguments
 
 Your default config will be loaded and used.
@@ -100,7 +95,7 @@ sub new {
     if( $_[0] && IS_CONFOBJ->( conf => $_[0] ) ) {
         $conf = shift;
     } else {
-        $conf = CPANPLUS::Configure->new( @_ ) or return;
+        $conf = CPANPLUS::Configure->new() or return;
     }
 
     my $self = $class->SUPER::_init( _conf => $conf );
@@ -457,7 +452,7 @@ sub parse_module {
     }
 
     unless( $dist ) {
-        cp_error( loc("%1 is not a proper distribution name!", $mod) );
+        error( loc("%1 is not a proper distribution name!", $mod) );
         return;
     }
     
@@ -573,10 +568,10 @@ sub parse_module {
     } else {
 
         unless( $author ) {
-            cp_error( loc( "'%1' does not contain an author part", $mod ) );
+            error( loc( "'%1' does not contain an author part", $mod ) );
         }
 
-        cp_error( loc( "Cannot find '%1' in the module tree", $mod ) );
+        error( loc( "Cannot find '%1' in the module tree", $mod ) );
     }
 
     return;
@@ -624,7 +619,7 @@ sub reload_indices {
                                 verbose     => $conf->get_conf('verbose'),
                             );
 
-    cp_error( loc( "Error rebuilding source trees!" ) );
+    error( loc( "Error rebuilding source trees!" ) );
 
     return;
 }
@@ -689,7 +684,7 @@ sub flush {
 
     my $aref = $cache->{$type}
                     or (
-                        cp_error( loc("No such cache '%1'", $type) ),
+                        error( loc("No such cache '%1'", $type) ),
                         return
                     );
 
@@ -777,11 +772,11 @@ sub local_mirror {
 
     unless( -d $path ) {
         $self->_mkdir( dir => $path )
-                or( cp_error( loc( "Could not create '%1', giving up", $path ) ),
+                or( error( loc( "Could not create '%1', giving up", $path ) ),
                     return
                 );
     } elsif ( ! -w _ ) {
-        cp_error( loc( "Could not write to '%1', giving up", $path ) );
+        error( loc( "Could not write to '%1', giving up", $path ) );
         return;
     }
 
@@ -807,7 +802,7 @@ sub local_mirror {
                 $mod->_get_checksums_file(
                             %opts
                         ) or (
-                            cp_error( loc( "Could not fetch %1 file, " .
+                            error( loc( "Could not fetch %1 file, " .
                                         "skipping author '%2'",
                                         CHECKSUMS, $auth->cpanid ) ),
                             $flag++, next AUTHOR
@@ -815,7 +810,7 @@ sub local_mirror {
             }
 
             $mod->fetch( %opts )
-                    or( cp_error( loc( "Could not fetch '%1'", $mod->module ) ),
+                    or( error( loc( "Could not fetch '%1'", $mod->module ) ),
                         $flag++, next MODULE
                     );
         } }
@@ -872,7 +867,7 @@ sub autobundle {
 
     unless( -d $path ) {
         $self->_mkdir( dir => $path )
-                or( cp_error(loc("Could not create directory '%1'", $path ) ),
+                or( error(loc("Could not create directory '%1'", $path ) ),
                     return
                 );
     }
@@ -897,7 +892,7 @@ sub autobundle {
     }
     my $fh;
     unless( $fh = FileHandle->new( ">$file" ) ) {
-        cp_error( loc( "Could not open '%1' for writing: %2", $file, $! ) );
+        error( loc( "Could not open '%1' for writing: %2", $file, $! ) );
         return;
     }
 
